.. _contributing:

==============
 Contributing
==============

The contributing guide goes over the details necessary to contribute to SymPy.
See also the full `Development Workflow
<https://github.com/sympy/sympy/wiki/Development-workflow>`_ guide on the
SymPy wiki.

**Content**

.. toctree::
   :maxdepth: 2

   dev-setup.rst
   dependencies.md
   build-docs.rst
   debug.rst
   docstring.rst
   documentation-style-guide.rst
   make-a-contribution.rst
   deprecations.md
